import { ThemeInput, LanguageInput, CodeToHtmlOptions } from './types.js';
export { Awaitable, BuiltinLanguages, BuiltinThemes, ElementsOptions, HtmlRendererOptions, LanguageRegistration, LineOption, MaybeGetter, ThemeRegisteration, ThemeRegisterationRaw } from './types.js';

/*---------------------------------------------------------
 * Copyright (C) Microsoft Corporation. All rights reserved.
 *--------------------------------------------------------*/

interface WebAssemblyInstantiator$1 {
	(importObject: Record<string, Record<string, WebAssembly.ImportValue>> | undefined): Promise<WebAssembly.WebAssemblyInstantiatedSource>;
}
interface ICommonOptions$1 {
	print?(str: string): void;
}
interface IInstantiatorOptions$1 extends ICommonOptions$1 {
	instantiator: WebAssemblyInstantiator$1;
}
interface IDataOptions$1 extends ICommonOptions$1 {
	data: ArrayBuffer | Response;
}
type IOptions$1 = IInstantiatorOptions$1 | IDataOptions$1;

interface WebAssemblyInstantiator {
    (importObject: Record<string, Record<string, WebAssembly.ImportValue>> | undefined): Promise<WebAssembly.WebAssemblyInstantiatedSource | WebAssembly.Instance>;
}
interface ICommonOptions {
    print?(str: string): void;
}
interface IInstantiatorOptions extends ICommonOptions {
    instantiator: WebAssemblyInstantiator;
}
interface IDataOptions extends ICommonOptions {
    data: ArrayBufferView | ArrayBuffer | Response;
}
type IOptions = IInstantiatorOptions | IDataOptions;
declare function loadWasm(loader: WebAssemblyInstantiator): Promise<void>;
declare function loadWasm(options: IOptions): Promise<void>;
declare function loadWasm(data: ArrayBufferView | ArrayBuffer | Response): Promise<void>;

interface CoreHighlighterOptions {
    themes: ThemeInput[];
    langs: LanguageInput[];
    loadWasm?: IOptions$1 | (() => Promise<IOptions$1>);
}

declare function getHighlighter(options: CoreHighlighterOptions): Promise<{
    codeToThemedTokens: (code: string, lang?: string, theme?: string, options?: {
        includeExplanation: boolean;
    }) => {
        content: string;
    }[][];
    codeToHtml: (code: string, options?: CodeToHtmlOptions) => string;
}>;

export { CodeToHtmlOptions, CoreHighlighterOptions, LanguageInput, ThemeInput, getHighlighter, loadWasm };
